@@ -27,7 +27,7 @@ from _discord.errors import DiscordException
 class SinkException(DiscordException):
     """Raised when a Sink error occurs.
 
-    .. versionadded:: 2.1
+    .. versionadded:: 2.0
     """
 
 
@@ -35,56 +35,54 @@ class RecordingException(SinkException):
     """Exception that's thrown when there is an error while trying to record
     audio from a voice channel.
 
-    .. versionadded:: 2.1
+    .. versionadded:: 2.0
     """
 
-    pass
-
 
 class MP3SinkError(SinkException):
-    """Exception thrown when a exception occurs with :class:`MP3Sink`
+    """Exception thrown when an exception occurs with :class:`MP3Sink`
 
-    .. versionadded:: 2.1
+    .. versionadded:: 2.0
     """
 
 
 class MP4SinkError(SinkException):
-    """Exception thrown when a exception occurs with :class:`MP4Sink`
+    """Exception thrown when an exception occurs with :class:`MP4Sink`
 
-    .. versionadded:: 2.1
+    .. versionadded:: 2.0
     """
 
 
 class OGGSinkError(SinkException):
-    """Exception thrown when a exception occurs with :class:`OGGSink`
+    """Exception thrown when an exception occurs with :class:`OGGSink`
 
-    .. versionadded:: 2.1
+    .. versionadded:: 2.0
     """
 
 
 class MKVSinkError(SinkException):
-    """Exception thrown when a exception occurs with :class:`MKVSink`
+    """Exception thrown when an exception occurs with :class:`MKVSink`
 
-    .. versionadded:: 2.1
+    .. versionadded:: 2.0
     """
 
 
 class WaveSinkError(SinkException):
-    """Exception thrown when a exception occurs with :class:`WaveSink`
+    """Exception thrown when an exception occurs with :class:`WaveSink`
 
-    .. versionadded:: 2.1
+    .. versionadded:: 2.0
     """
 
 
 class M4ASinkError(SinkException):
-    """Exception thrown when a exception occurs with :class:`M4ASink`
+    """Exception thrown when an exception occurs with :class:`M4ASink`
 
-    .. versionadded:: 2.1
+    .. versionadded:: 2.0
     """
 
 
 class MKASinkError(SinkException):
-    """Exception thrown when a exception occurs with :class:`MKAsSink`
+    """Exception thrown when an exception occurs with :class:`MKASink`
 
-    .. versionadded:: 2.1
+    .. versionadded:: 2.0
     """
