@@ -25,7 +25,7 @@ DEALINGS IN THE SOFTWARE.
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Callable, Dict, Iterable, List, Optional, Union
+from typing import TYPE_CHECKING, Callable, Iterable
 
 from .abc import Messageable, _purge_messages_helper
 from .enums import ChannelType, try_enum
@@ -79,7 +79,7 @@ class Thread(Messageable, Hashable):
     .. versionadded:: 2.0
 
     Attributes
-    -----------
+    ----------
     name: :class:`str`
         The thread name.
     guild: :class:`Guild`
@@ -156,7 +156,7 @@ class Thread(Messageable, Hashable):
     def __init__(self, *, guild: Guild, state: ConnectionState, data: ThreadPayload):
         self._state: ConnectionState = state
         self.guild = guild
-        self._members: Dict[int, ThreadMember] = {}
+        self._members: dict[int, ThreadMember] = {}
         self._from_data(data)
 
     async def _get_channel(self):
@@ -179,7 +179,11 @@ class Thread(Messageable, Hashable):
         self._type = try_enum(ChannelType, data["type"])
 
         # This data may be missing depending on how this object is being created
-        self.owner_id = int(data.get("owner_id")) if data.get("owner_id", None) is not None else None
+        self.owner_id = (
+            int(data.get("owner_id"))
+            if data.get("owner_id", None) is not None
+            else None
+        )
         self.last_message_id = _get_as_snowflake(data, "last_message_id")
         self.slowmode_delay = data.get("rate_limit_per_user", 0)
         self.message_count = data.get("message_count", None)
@@ -189,9 +193,19 @@ class Thread(Messageable, Hashable):
         # Here, we try to fill in potentially missing data
         if thread := self.guild.get_thread(self.id) and data.pop("_invoke_flag", False):
             self.owner_id = thread.owner_id if self.owner_id is None else self.owner_id
-            self.last_message_id = thread.last_message_id if self.last_message_id is None else self.last_message_id
-            self.message_count = thread.message_count if self.message_count is None else self.message_count
-            self.member_count = thread.member_count if self.member_count is None else self.member_count
+            self.last_message_id = (
+                thread.last_message_id
+                if self.last_message_id is None
+                else self.last_message_id
+            )
+            self.message_count = (
+                thread.message_count
+                if self.message_count is None
+                else self.message_count
+            )
+            self.member_count = (
+                thread.member_count if self.member_count is None else self.member_count
+            )
 
         self._unroll_metadata(data["thread_metadata"])
 
@@ -206,9 +220,9 @@ class Thread(Messageable, Hashable):
         self.archived = data["archived"]
         self.auto_archive_duration = data["auto_archive_duration"]
         self.archive_timestamp = parse_time(data["archive_timestamp"])
-        self.locked = data.get("locked", False)
+        self.locked = data["locked"]
         self.invitable = data.get("invitable", True)
-        self.created_at = parse_time(data.get("create_timestamp"))
+        self.created_at = parse_time(data.get("create_timestamp", None))
 
     def _update(self, data):
         try:
@@ -230,12 +244,12 @@ class Thread(Messageable, Hashable):
         return self._type
 
     @property
-    def parent(self) -> Optional[Union[TextChannel, ForumChannel]]:
+    def parent(self) -> TextChannel | ForumChannel | None:
         """Optional[:class:`TextChannel`]: The parent channel this thread belongs to."""
         return self.guild.get_channel(self.parent_id)  # type: ignore
 
     @property
-    def owner(self) -> Optional[Member]:
+    def owner(self) -> Member | None:
         """Optional[:class:`Member`]: The member this thread belongs to."""
         return self.guild.get_member(self.owner_id)
 
@@ -253,7 +267,7 @@ class Thread(Messageable, Hashable):
         return f"https://discord.com/channels/{self.guild.id}/{self.id}"
 
     @property
-    def members(self) -> List[ThreadMember]:
+    def members(self) -> list[ThreadMember]:
         """List[:class:`ThreadMember`]: A list of thread members in this thread.
 
         This requires :attr:`Intents.members` to be properly filled. Most of the time however,
@@ -263,7 +277,7 @@ class Thread(Messageable, Hashable):
         return list(self._members.values())
 
     @property
-    def last_message(self) -> Optional[Message]:
+    def last_message(self) -> Message | None:
         """Returns the last message from this thread in cache.
 
         The message might not be valid or point to an existing message.
@@ -277,25 +291,29 @@ class Thread(Messageable, Hashable):
             attribute.
 
         Returns
-        --------
+        -------
         Optional[:class:`Message`]
             The last message in this channel or ``None`` if not found.
         """
-        return self._state._get_message(self.last_message_id) if self.last_message_id else None
+        return (
+            self._state._get_message(self.last_message_id)
+            if self.last_message_id
+            else None
+        )
 
     @property
-    def category(self) -> Optional[CategoryChannel]:
+    def category(self) -> CategoryChannel | None:
         """The category channel the parent channel belongs to, if applicable.
 
-        Raises
-        -------
-        ClientException
-            The parent channel was not cached and returned ``None``.
-
         Returns
-        --------
+        -------
         Optional[:class:`CategoryChannel`]
             The parent channel's category.
+
+        Raises
+        ------
+        ClientException
+            The parent channel was not cached and returned ``None``.
         """
 
         parent = self.parent
@@ -304,18 +322,18 @@ class Thread(Messageable, Hashable):
         return parent.category
 
     @property
-    def category_id(self) -> Optional[int]:
+    def category_id(self) -> int | None:
         """The category channel ID the parent channel belongs to, if applicable.
 
-        Raises
-        -------
-        ClientException
-            The parent channel was not cached and returned ``None``.
-
         Returns
-        --------
+        -------
         Optional[:class:`int`]
             The parent channel's category ID.
+
+        Raises
+        ------
+        ClientException
+            The parent channel was not cached and returned ``None``.
         """
 
         parent = self.parent
@@ -324,7 +342,7 @@ class Thread(Messageable, Hashable):
         return parent.category_id
 
     @property
-    def starting_message(self) -> Optional[Message]:
+    def starting_message(self) -> Message | None:
         """Returns the message that started this thread.
 
         The message might not be valid or point to an existing message.
@@ -333,7 +351,7 @@ class Thread(Messageable, Hashable):
             The ID for this message is the same as the thread ID.
 
         Returns
-        --------
+        -------
         Optional[:class:`Message`]
             The message that started this thread or ``None`` if not found in the cache.
         """
@@ -364,7 +382,7 @@ class Thread(Messageable, Hashable):
         parent = self.parent
         return parent is not None and parent.is_nsfw()
 
-    def permissions_for(self, obj: Union[Member, Role], /) -> Permissions:
+    def permissions_for(self, obj: Member | Role, /) -> Permissions:
         """Handles permission resolution for the :class:`~discord.Member`
         or :class:`~discord.Role`.
 
@@ -380,15 +398,15 @@ class Thread(Messageable, Hashable):
             a member or a role. If it's a role then member overwrites
             are not computed.
 
-        Raises
-        -------
-        ClientException
-            The parent channel was not cached and returned ``None``
-
         Returns
         -------
         :class:`~discord.Permissions`
             The resolved permissions for the member or role.
+
+        Raises
+        ------
+        ClientException
+            The parent channel was not cached and returned ``None``
         """
 
         parent = self.parent
@@ -396,7 +414,9 @@ class Thread(Messageable, Hashable):
             raise ClientException("Parent channel not found")
         return parent.permissions_for(obj)
 
-    async def delete_messages(self, messages: Iterable[Snowflake], *, reason: Optional[str] = None) -> None:
+    async def delete_messages(
+        self, messages: Iterable[Snowflake], *, reason: str | None = None
+    ) -> None:
         """|coro|
 
         Deletes a list of messages. This is similar to :meth:`Message.delete`
@@ -415,7 +435,7 @@ class Thread(Messageable, Hashable):
         Usable only by bot accounts.
 
         Parameters
-        -----------
+        ----------
         messages: Iterable[:class:`abc.Snowflake`]
             An iterable of messages denoting which ones to bulk delete.
         reason: Optional[:class:`str`]
@@ -426,7 +446,7 @@ class Thread(Messageable, Hashable):
         ClientException
             The number of messages to delete was more than 100.
         Forbidden
-            You do not have proper permissions to delete the messages or
+            You do not have proper permissions to delete the messages, or
             you're not using a bot account.
         NotFound
             If single delete, then the message was already deleted.
@@ -453,15 +473,15 @@ class Thread(Messageable, Hashable):
     async def purge(
         self,
         *,
-        limit: Optional[int] = 100,
+        limit: int | None = 100,
         check: Callable[[Message], bool] = MISSING,
-        before: Optional[SnowflakeTime] = None,
-        after: Optional[SnowflakeTime] = None,
-        around: Optional[SnowflakeTime] = None,
-        oldest_first: Optional[bool] = False,
+        before: SnowflakeTime | None = None,
+        after: SnowflakeTime | None = None,
+        around: SnowflakeTime | None = None,
+        oldest_first: bool | None = False,
         bulk: bool = True,
-        reason: Optional[str] = None,
-    ) -> List[Message]:
+        reason: str | None = None,
+    ) -> list[Message]:
         """|coro|
 
         Purges a list of messages that meet the criteria given by the predicate
@@ -473,19 +493,8 @@ class Thread(Messageable, Hashable):
         account). The :attr:`~Permissions.read_message_history` permission is
         also needed to retrieve message history.
 
-        Examples
-        ---------
-
-        Deleting bot's messages ::
-
-            def is_me(m):
-                return m.author == client.user
-
-            deleted = await thread.purge(limit=100, check=is_me)
-            await thread.send(f'Deleted {len(deleted)} message(s)')
-
         Parameters
-        -----------
+        ----------
         limit: Optional[:class:`int`]
             The number of messages to search through. This is not the number
             of messages that will be deleted, though it can be.
@@ -507,17 +516,28 @@ class Thread(Messageable, Hashable):
         reason: Optional[:class:`str`]
             The reason for deleting the messages. Shows up on the audit log.
 
-        Raises
+        Returns
         -------
+        List[:class:`.Message`]
+            The list of messages that were deleted.
+
+        Raises
+        ------
         Forbidden
             You do not have proper permissions to do the actions required.
         HTTPException
             Purging the messages failed.
 
-        Returns
+        Examples
         --------
-        List[:class:`.Message`]
-            The list of messages that were deleted.
+
+        Deleting bot's messages ::
+
+            def is_me(m):
+                return m.author == client.user
+
+            deleted = await thread.purge(limit=100, check=is_me)
+            await thread.send(f'Deleted {len(deleted)} message(s)')
         """
         return await _purge_messages_helper(
             self,
@@ -541,7 +561,7 @@ class Thread(Messageable, Hashable):
         slowmode_delay: int = MISSING,
         auto_archive_duration: ThreadArchiveDuration = MISSING,
         pinned: bool = MISSING,
-        reason: Optional[str] = None,
+        reason: str | None = None,
     ) -> Thread:
         """|coro|
 
@@ -555,7 +575,7 @@ class Thread(Messageable, Hashable):
         The thread must be unarchived to be edited.
 
         Parameters
-        ------------
+        ----------
         name: :class:`str`
             The new name of the thread.
         archived: :class:`bool`
@@ -576,17 +596,17 @@ class Thread(Messageable, Hashable):
         pinned: :class:`bool`
             Whether to pin the thread or not. This only works if the thread is part of a forum.
 
-        Raises
+        Returns
         -------
+        :class:`Thread`
+            The newly edited thread.
+
+        Raises
+        ------
         Forbidden
             You do not have permissions to edit the thread.
         HTTPException
             Editing the thread failed.
-
-        Returns
-        --------
-        :class:`Thread`
-            The newly edited thread.
         """
         payload = {}
         if name is not MISSING:
@@ -617,13 +637,12 @@ class Thread(Messageable, Hashable):
         Archives the thread. This is a shorthand of :meth:`.edit`.
 
         Parameters
-        ------------
+        ----------
         locked: :class:`bool`
             Whether to lock the thread on archive, Defaults to ``False``.
 
-
         Returns
-        --------
+        -------
         :class:`.Thread`
             The updated thread.
         """
@@ -635,7 +654,7 @@ class Thread(Messageable, Hashable):
         Unarchives the thread. This is a shorthand of :meth:`.edit`.
 
         Returns
-        --------
+        -------
         :class:`.Thread`
             The updated thread.
         """
@@ -650,7 +669,7 @@ class Thread(Messageable, Hashable):
         If the thread is private, :attr:`~Permissions.manage_threads` is also needed.
 
         Raises
-        -------
+        ------
         Forbidden
             You do not have permissions to join the thread.
         HTTPException
@@ -664,7 +683,7 @@ class Thread(Messageable, Hashable):
         Leaves this thread.
 
         Raises
-        -------
+        ------
         HTTPException
             Leaving the thread failed.
         """
@@ -675,18 +694,18 @@ class Thread(Messageable, Hashable):
 
         Adds a user to this thread.
 
-        You must have :attr:`~Permissions.send_messages` and :attr:`~Permissions.use_threads`
-        to add a user to a public thread. If the thread is private then :attr:`~Permissions.send_messages`
-        and either :attr:`~Permissions.use_private_threads` or :attr:`~Permissions.manage_messages`
-        is required to add a user to the thread.
+        You must have :attr:`~Permissions.send_messages_in_threads`
+        to add a user to a public thread. If the thread is private and
+        :attr:`invitable` is ``False``, then
+        :attr:`~Permissions.manage_threads` is required.
 
         Parameters
-        -----------
+        ----------
         user: :class:`abc.Snowflake`
             The user to add to the thread.
 
         Raises
-        -------
+        ------
         Forbidden
             You do not have permissions to add the user to the thread.
         HTTPException
@@ -702,12 +721,12 @@ class Thread(Messageable, Hashable):
         You must have :attr:`~Permissions.manage_threads` or be the creator of the thread to remove a user.
 
         Parameters
-        -----------
+        ----------
         user: :class:`abc.Snowflake`
             The user to remove from the thread.
 
         Raises
-        -------
+        ------
         Forbidden
             You do not have permissions to remove the user from the thread.
         HTTPException
@@ -715,7 +734,7 @@ class Thread(Messageable, Hashable):
         """
         await self._state.http.remove_user_from_thread(self.id, user.id)
 
-    async def fetch_members(self) -> List[ThreadMember]:
+    async def fetch_members(self) -> list[ThreadMember]:
         """|coro|
 
         Retrieves all :class:`ThreadMember` that are in this thread.
@@ -723,15 +742,15 @@ class Thread(Messageable, Hashable):
         This requires :attr:`Intents.members` to get information about members
         other than yourself.
 
-        Raises
-        -------
-        HTTPException
-            Retrieving the members failed.
-
         Returns
-        --------
+        -------
         List[:class:`ThreadMember`]
             All thread members in the thread.
+
+        Raises
+        ------
+        HTTPException
+            Retrieving the members failed.
         """
 
         members = await self._state.http.get_thread_members(self.id)
@@ -751,7 +770,7 @@ class Thread(Messageable, Hashable):
         You must have :attr:`~Permissions.manage_threads` to delete threads.
 
         Raises
-        -------
+        ------
         Forbidden
             You do not have permissions to delete this thread.
         HTTPException
@@ -768,12 +787,12 @@ class Thread(Messageable, Hashable):
         .. versionadded:: 2.0
 
         Parameters
-        ------------
+        ----------
         message_id: :class:`int`
             The message ID to create a partial message for.
 
         Returns
-        ---------
+        -------
         :class:`PartialMessage`
             The partial message.
         """
@@ -785,7 +804,7 @@ class Thread(Messageable, Hashable):
     def _add_member(self, member: ThreadMember) -> None:
         self._members[member.id] = member
 
-    def _pop_member(self, member_id: int) -> Optional[ThreadMember]:
+    def _pop_member(self, member_id: int) -> ThreadMember | None:
         return self._members.pop(member_id, None)
 
 
@@ -813,7 +832,7 @@ class ThreadMember(Hashable):
     .. versionadded:: 2.0
 
     Attributes
-    -----------
+    ----------
     id: :class:`int`
         The thread member's ID.
     thread_id: :class:`int`
