@@ -9,12 +9,10 @@ from typeguard import typechecked
 
 from .base import *
 from ..dtypes import *
-from ..tracing import *
-from ..common import *
-from ..exceptions import *
+from ..logging.tracing import *
 
 from .. import client
-from .. import sql
+from ..logging import sql
 from .. import misc
 from .. import dtypes
 
@@ -32,9 +30,13 @@ class GLOBALS:
     """
     voice_client: discord.VoiceClient = None
 
+# Configuration
+# ----------------------#
+C_VC_CONNECT_TIMEOUT = 3 # Timeout of voice channels
 
-@typechecked
-@sql._register_type("MessageTYPE")
+
+@misc.doc_category("Messages", path="message")
+@sql.register_type("MessageTYPE")
 class VoiceMESSAGE(BaseMESSAGE):
     """
     This class is used for creating objects that represent messages which will be streamed to voice channels.
@@ -57,7 +59,6 @@ class VoiceMESSAGE(BaseMESSAGE):
 
         - None - Use this value for a fixed (not randomized) sending period
         - timedelta object - object describing time difference, if this is used, then the parameter represents the bottom limit of the **randomized** sending period.
-
     end_period: int
         If ``start_period`` is not None, then this represents the upper limit of randomized time period in which messages will be sent.
         If ``start_period`` is None, then this represents the actual time period between each message send.
@@ -66,19 +67,21 @@ class VoiceMESSAGE(BaseMESSAGE):
             :caption: **Randomized** sending period between **5** seconds and **10** seconds.
 
             # Time between each send is somewhere between 5 seconds and 10 seconds.
-            daf.VoiceMESSAGE(start_period=timedelta(5), end_period=timedelta(10), data=daf.AUDIO("msg.mp3"), channels=[12345], start_in=timedelta(seconds=0), volume=50)
+            daf.VoiceMESSAGE(start_period=timedelta(seconds=5), end_period=timedelta(seconds=10), data=daf.AUDIO("msg.mp3"), channels=[12345], start_in=timedelta(seconds=0), volume=50)
 
         .. code-block:: python
             :caption: **Fixed** sending period at **10** seconds
 
             # Time between each send is exactly 10 seconds.
-            daf.VoiceMESSAGE(start_period=None, end_period=timedelta(10), data=daf.AUDIO("msg.mp3"), channels=[12345], start_in=timedelta(seconds=0), volume=50)
-
+            daf.VoiceMESSAGE(start_period=None, end_period=timedelta(seconds=10), data=daf.AUDIO("msg.mp3"), channels=[12345], start_in=timedelta(seconds=0), volume=50)
     data: AUDIO
         The data parameter is the actual data that will be sent using discord's API. The data types of this parameter can be:
             - AUDIO object.
             - Function that accepts any amount of parameters and returns an AUDIO object. To pass a function, YOU MUST USE THE :ref:`data_function` decorator on the function before passing the function to the daf.
-    channels: Iterable[Union[int, discord.VoiceChannel]]
+    channels: Union[Iterable[Union[int, discord.VoiceChannel]], daf.message.AutoCHANNEL]
+        .. versionchanged:: v2.3
+            Can also be :class:`~daf.message.AutoCHANNEL`
+
         Channels that it will be advertised into (Can be snowflake ID or channel objects from PyCord).
     volume: int
         The volume (0-100%) at which to play the audio. Defaults to 50%. This was added in v2.0.0
@@ -102,13 +105,12 @@ class VoiceMESSAGE(BaseMESSAGE):
         "channels",
     )
 
-    __logname__ = "VoiceMESSAGE"    # For sql._register_type
-
+    @typechecked
     def __init__(self,
                  start_period: Union[int, timedelta, None],
                  end_period: Union[int, timedelta],
-                 data: Union[AUDIO, _FunctionBaseCLASS],
-                 channels: Iterable[Union[int, discord.VoiceChannel]],
+                 data: Union[AUDIO, Iterable[AUDIO], _FunctionBaseCLASS],
+                 channels: Union[Iterable[Union[int, discord.VoiceChannel]], AutoCHANNEL],
                  volume: int=50,
                  start_in: Union[timedelta, bool]=timedelta(seconds=0),
                  remove_after: Optional[Union[int, timedelta, datetime]]=None):
@@ -118,7 +120,7 @@ class VoiceMESSAGE(BaseMESSAGE):
 
         super().__init__(start_period, end_period, data, start_in, remove_after)
         self.volume = max(0, min(100, volume)) # Clamp the volume to 0-100 %
-        self.channels = list(set(channels))    # Auto remove duplicates
+        self.channels = channels
 
     def _check_state(self) -> bool:
         """
@@ -145,7 +147,7 @@ class VoiceMESSAGE(BaseMESSAGE):
                     reason.code in {50007, 10003}):     # Not Forbidden, but bad error codes
                     self.channels.remove(channel)
 
-    def _generate_log_context(self,
+    def generate_log_context(self,
                              audio: AUDIO,
                              succeeded_ch: List[discord.VoiceChannel],
                              failed_ch: List[Dict[str, Any]]) -> Dict[str, Any]:
@@ -164,16 +166,29 @@ class VoiceMESSAGE(BaseMESSAGE):
         Returns
         ----------
         Dict[str, Any]
-            Dictionary containing:
-
-                - sent_data: Dict[str, str]:
-                    - streamed_audio: str - The filename that was streamed/youtube url
-
-                - channels: Dict[str, List]:
-                    - successful: List[Dict[str, int]] - List of dictionaries containing name of the channel and snowflake id of the channels.
-                    - failed: List[Dict[str, Any]] - List of dictionaries containing name of the channel (str), snowflake id (int) and reason why streaming to channel failed (str).
-
-                - type: str - The type of the message, this is always VoiceMESSAGE.
+            .. code-block:: python
+              
+                {
+                    sent_data:
+                    {
+                        streamed_audio: str - The filename that was streamed/youtube url
+                    },
+                    channels:
+                    {
+                        successful:
+                        {
+                            id: int - Snowflake id,
+                            name: str - Channel name
+                        },
+                        failed:
+                        {
+                            id: int - Snowflake id,
+                            name: str - Channel name,
+                            reason: str - Exception that caused the error
+                        }
+                    },
+                    type: str - The type of the message, this is always VoiceMESSAGE.
+              }
         """
 
         succeeded_ch = [{"name": str(channel), "id" : channel.id} for channel in succeeded_ch]
@@ -190,14 +205,17 @@ class VoiceMESSAGE(BaseMESSAGE):
             "type" : type(self).__name__
         }
 
-    def _get_data(self) -> dict:
+    async def _get_data(self) -> dict:
         """"
         Returns a dictionary of keyword arguments that is then expanded
         into other methods eg. `_send_channel, _generate_log`
+        
+        .. versionchanged:: v2.3
+            Turned async.
         """
         data = None
         _data_to_send = {}
-        data = self.data.get_data() if isinstance(self.data, _FunctionBaseCLASS) else self.data
+        data = await super()._get_data()
         if data is not None:
             if not isinstance(data, (list, tuple, set)):
                 data = (data,)
@@ -211,9 +229,9 @@ class VoiceMESSAGE(BaseMESSAGE):
         This method initializes the implementation specific api objects and checks for the correct channel input context.
 
         Parameters
-        ------------
+        --------------
         parent: daf.guild.GUILD
-            The GUILD this message is in.
+            The GUILD this message is in
 
         Raises
         ------------
@@ -227,26 +245,32 @@ class VoiceMESSAGE(BaseMESSAGE):
         ch_i = 0
         cl = client.get_client()
         self.parent = parent
-        _guild = parent.apiobject
-        while ch_i < len(self.channels):
-            channel = self.channels[ch_i]
-            if isinstance(channel, discord.abc.GuildChannel):
-                channel_id = channel.id
-            else:
-                channel_id = channel
-                channel = self.channels[ch_i] = cl.get_channel(channel_id)
+        _guild = self.parent.apiobject
+        to_remove = []
 
-            if channel is None:
-                trace(f"Unable to get channel from ID {channel_id}", TraceLEVELS.ERROR)
+        if isinstance(self.channels, AutoCHANNEL):
+            await self.channels.initialize(self, "voice_channels")
+        else:
+            for ch_i, channel in enumerate(self.channels):
+                if isinstance(channel, discord.abc.GuildChannel):
+                    channel_id = channel.id
+                else:
+                    # Snowflake IDs provided
+                    channel_id = channel
+                    channel = self.channels[ch_i] = cl.get_channel(channel_id)
+
+                if channel is None:
+                    trace(f"Unable to get channel from ID {channel_id}", TraceLEVELS.WARNING)
+                    to_remove.append(channel)
+                elif type(channel) is not discord.VoiceChannel:
+                    raise TypeError(f"VoiceMESSAGE object received channel type of {type(channel).__name__}, but was expecting discord.VoiceChannel")
+                elif channel.guild != _guild:
+                    raise ValueError(f"The channel {channel.name}(ID: {channel_id}) does not belong into {_guild.name}(ID: {_guild.id}) but is part of {channel.guild.name}(ID: {channel.guild.id})")
+            
+            for channel in to_remove:
                 self.channels.remove(channel)
-            elif type(channel) not in {discord.VoiceChannel}:
-                raise TypeError(f"TextMESSAGE object received channel type of {type(channel).__name__}, but was expecting VoiceChannel")
-            elif channel.guild != _guild:
-                raise ValueError(f"The channel {channel.name}(ID: {channel_id}) does not belong into {_guild.name}(ID: {_guild.id}) but is part of {channel.guild.name}(ID: {channel.guild.id})")
-            else:
-                ch_i += 1
 
-        if not len(self.channels):
+        if not self.channels:
             raise ValueError(f"No valid channels were passed to {self} object")
 
     async def _send_channel(self,
@@ -306,11 +330,11 @@ class VoiceMESSAGE(BaseMESSAGE):
         Returns
         ----------
         Union[Dict, None]
-            Returns a dictionary generated by the ``_generate_log_context`` method or the None object if message wasn't ready to be sent (:ref:`data_function` returned None or an invalid type)
+            Returns a dictionary generated by the ``generate_log_context`` method or the None object if message wasn't ready to be sent (:ref:`data_function` returned None or an invalid type)
 
             This is then passed to :ref:`GUILD`._generate_log method.
         """
-        _data_to_send = self._get_data()
+        _data_to_send = await self._get_data()
         if any(_data_to_send.values()):
             errored_channels = []
             succeeded_channels= []
@@ -323,10 +347,11 @@ class VoiceMESSAGE(BaseMESSAGE):
                     errored_channels.append({"channel":channel, "reason": context["reason"]})
 
             self._update_state(errored_channels)
-            return self._generate_log_context(**_data_to_send, succeeded_ch=succeeded_channels, failed_ch=errored_channels)
+            return self.generate_log_context(**_data_to_send, succeeded_ch=succeeded_channels, failed_ch=errored_channels)
 
         return None
 
+    @typechecked
     @misc._async_safe("update_semaphore")
     async def update(self, _init_options: Optional[dict] = {}, **kwargs):
         """
@@ -352,8 +377,11 @@ class VoiceMESSAGE(BaseMESSAGE):
         if "start_in" not in kwargs:
             # This parameter does not appear as attribute, manual setting necessary
             kwargs["start_in"] = timedelta(seconds=0)
+
+        if "data" not in kwargs:
+            kwargs["data"] = self._data
         
         if not len(_init_options):
-            _init_options = {"guild": self.parent}
+            _init_options = {"parent": self.parent}
 
         await misc._update(self, init_options=_init_options, **kwargs) # No additional modifications are required
